# CDK Metaflow

The `cdk-metaflow` package contains cdk constructs for deploying metaflow infrastructure on aws.

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
import cdk_metaflow as metaflow
```

## Metaflow

The main construct creates all the required infrastructure for getting up and running with Metaflow on AWS. This is achieved by creating an instance of `Metaflow`:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
metaflow = Metaflow(self, "metaflow")
```
